<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="en_US">
<context>
    <name>GB2::LocalWorkflow::SiteconBuildPrompter</name>
    <message>
        <location filename="../src/SiteconBuildWorker.cpp" line="100"/>
        <source>For each MSA from &lt;u&gt;%1&lt;/u&gt;,</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/SiteconBuildWorker.cpp" line="101"/>
        <source>%1 build SITECON model.</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>GB2::LocalWorkflow::SiteconBuildWorker</name>
    <message>
        <location filename="../src/SiteconBuildWorker.cpp" line="62"/>
        <source>Build SITECON model</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/SiteconBuildWorker.cpp" line="143"/>
        <source>Built SITECON model from: %1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/SiteconBuildWorker.cpp" line="40"/>
        <source>Input alignment</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/SiteconBuildWorker.cpp" line="46"/>
        <source>Sitecon model</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/SiteconBuildWorker.cpp" line="41"/>
        <source>Origin</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/SiteconBuildWorker.cpp" line="51"/>
        <source>Window size, bp</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/SiteconBuildWorker.cpp" line="52"/>
        <source>Calibration length</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/SiteconBuildWorker.cpp" line="53"/>
        <source>Random seed</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/SiteconBuildWorker.cpp" line="54"/>
        <source>Weight algorithm</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/SiteconBuildWorker.cpp" line="40"/>
        <source>Input multiple sequence alignment for building statistical model.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/SiteconBuildWorker.cpp" line="41"/>
        <source>Location of input alignment, used as optional hint for model description.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/SiteconBuildWorker.cpp" line="46"/>
        <source>Produced statistical model of specified TFBS data.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/SiteconBuildWorker.cpp" line="63"/>
        <source>Builds statistical profile for SITECON. The SITECON is a program for probabilistic recognition of transcription factor binding sites.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/SiteconBuildWorker.cpp" line="85"/>
        <source>None</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/SiteconBuildWorker.cpp" line="86"/>
        <source>Algorithm2</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>GB2::LocalWorkflow::SiteconReadPrompter</name>
    <message>
        <location filename="../src/SiteconIOWorkers.cpp" line="151"/>
        <source>Read model(s) from &lt;u&gt;%1&lt;/u&gt;</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>GB2::LocalWorkflow::SiteconReader</name>
    <message>
        <location filename="../src/SiteconIOWorkers.cpp" line="192"/>
        <source>Loaded SITECON model from %1</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>GB2::LocalWorkflow::SiteconSearchPrompter</name>
    <message>
        <location filename="../src/SiteconSearchWorker.cpp" line="103"/>
        <source>For each sequence from &lt;u&gt;%1&lt;/u&gt;,</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/SiteconSearchWorker.cpp" line="115"/>
        <source>%1 search transcription factor binding sites (TFBS) %2.&lt;br&gt;Recognize sites with &lt;u&gt;similarity %3%&lt;/u&gt;, process &lt;u&gt;%4&lt;/u&gt;.&lt;br&gt;Output the list of found regions annotated as &lt;u&gt;%5&lt;/u&gt;.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/SiteconSearchWorker.cpp" line="104"/>
        <source>with all profiles provided by &lt;u&gt;%1&lt;/u&gt;,</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>GB2::LocalWorkflow::SiteconSearchWorker</name>
    <message>
        <location filename="../src/SiteconSearchWorker.cpp" line="88"/>
        <location filename="../src/SiteconSearchWorker.cpp" line="110"/>
        <source>both strands</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/SiteconSearchWorker.cpp" line="89"/>
        <location filename="../src/SiteconSearchWorker.cpp" line="111"/>
        <source>direct strand</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/SiteconSearchWorker.cpp" line="90"/>
        <location filename="../src/SiteconSearchWorker.cpp" line="112"/>
        <source>complement strand</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/SiteconSearchWorker.cpp" line="45"/>
        <source>Sitecon Model</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/SiteconSearchWorker.cpp" line="46"/>
        <source>Sequence</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/SiteconSearchWorker.cpp" line="47"/>
        <source>SITECON annotations</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/SiteconSearchWorker.cpp" line="53"/>
        <source>Result annotation</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/SiteconSearchWorker.cpp" line="54"/>
        <source>Search in</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/SiteconSearchWorker.cpp" line="168"/>
        <source>Search TFBS in %1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/SiteconSearchWorker.cpp" line="172"/>
        <source>Bad sequence supplied to SiteconSearch: %1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/SiteconSearchWorker.cpp" line="196"/>
        <source>Found %1 TFBS</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/SiteconSearchWorker.cpp" line="45"/>
        <source>Profile data to search with.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/SiteconSearchWorker.cpp" line="46"/>
        <source>Input nucleotide sequence to search in.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/SiteconSearchWorker.cpp" line="47"/>
        <source>Annotations marking found TFBS sites.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/SiteconSearchWorker.cpp" line="53"/>
        <source>Annotation name for marking found regions</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/SiteconSearchWorker.cpp" line="54"/>
        <source>Which strands should be searched: direct, complement or both.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/SiteconSearchWorker.cpp" line="67"/>
        <source>Search TFBS</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/SiteconSearchWorker.cpp" line="68"/>
        <source>Searches each input sequence for transcription factor binding sites significantly similar to specified SITECON profiles. In case several profiles were supplied, searches with all profiles one by one and outputs merged set of annotations for each sequence.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/SiteconSearchWorker.cpp" line="55"/>
        <source>Min score</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/SiteconSearchWorker.cpp" line="56"/>
        <source>Min Err1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/SiteconSearchWorker.cpp" line="56"/>
        <source>Alternative setting for filtering results, minimal value of Error type I.&lt;br&gt;Note that all thresholds (by score, by err1 and by err2) are applied when filtering results.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/SiteconSearchWorker.cpp" line="58"/>
        <source>Max Err2</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/SiteconSearchWorker.cpp" line="58"/>
        <source>Alternative setting for filtering results, max value of Error type II.&lt;br&gt;Note that all thresholds (by score, by err1 and by err2) are applied when filtering results.</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>GB2::LocalWorkflow::SiteconWritePrompter</name>
    <message>
        <location filename="../src/SiteconIOWorkers.cpp" line="161"/>
        <source>Save the profile(s) from &lt;u&gt;%1&lt;/u&gt; to %2.</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>GB2::LocalWorkflow::SiteconWriter</name>
    <message>
        <location filename="../src/SiteconIOWorkers.cpp" line="210"/>
        <source>Unspecified URL for writing Sitecon</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/SiteconIOWorkers.cpp" line="225"/>
        <source>Writing SITECON model to %1</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>GB2::SiteconADVContext</name>
    <message>
        <location filename="../src/SiteconPlugin.cpp" line="99"/>
        <source>run_sitecon</source>
        <translation>Search TFBS with SITECON</translation>
    </message>
</context>
<context>
    <name>GB2::SiteconBuildDialogController</name>
    <message>
        <location filename="../src/SiteconBuildDialogController.cpp" line="45"/>
        <source>select_file_with_alignment</source>
        <translation>Select file with alignment</translation>
    </message>
    <message>
        <location filename="../src/SiteconBuildDialogController.cpp" line="81"/>
        <source>illegal_in_file_name</source>
        <translation>Illegal alignment file</translation>
    </message>
    <message>
        <location filename="../src/SiteconBuildDialogController.cpp" line="86"/>
        <source>illegal_out_file_name</source>
        <translation>Illegal SITECON model file</translation>
    </message>
    <message>
        <location filename="../src/SiteconBuildDialogController.cpp" line="92"/>
        <source>error</source>
        <translation>Error</translation>
    </message>
    <message>
        <location filename="../src/SiteconBuildDialogController.cpp" line="104"/>
        <source>starting_calibration_process</source>
        <translation>Starting calibration process</translation>
    </message>
    <message>
        <location filename="../src/SiteconBuildDialogController.cpp" line="107"/>
        <source>hide_button</source>
        <translation>Hide</translation>
    </message>
    <message>
        <location filename="../src/SiteconBuildDialogController.cpp" line="108"/>
        <source>cancel_button</source>
        <translation>Cancel</translation>
    </message>
    <message>
        <location filename="../src/SiteconBuildDialogController.cpp" line="121"/>
        <source>build_finished_with_errors_%1</source>
        <translation>Build finished with error: %1</translation>
    </message>
    <message>
        <location filename="../src/SiteconBuildDialogController.cpp" line="123"/>
        <source>build_canceled</source>
        <translation>Build canceled</translation>
    </message>
    <message>
        <location filename="../src/SiteconBuildDialogController.cpp" line="125"/>
        <source>build_finished_successfuly</source>
        <translation>Build finished successfully</translation>
    </message>
    <message>
        <location filename="../src/SiteconBuildDialogController.cpp" line="127"/>
        <source>start_button</source>
        <translation>Build</translation>
    </message>
    <message>
        <location filename="../src/SiteconBuildDialogController.cpp" line="128"/>
        <source>close_button</source>
        <translation>Close</translation>
    </message>
    <message>
        <location filename="../src/SiteconBuildDialogController.cpp" line="134"/>
        <source>running_state_%1_progress_%2%</source>
        <translation>Running... State :%1 Progress: %2</translation>
    </message>
    <message>
        <location filename="../src/SiteconBuildDialogController.cpp" line="55"/>
        <source>Select file to save model to...</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>GB2::SiteconBuildTask</name>
    <message>
        <location filename="../src/SiteconBuildDialogController.cpp" line="149"/>
        <source>build_sitecon_model</source>
        <translation>Build SITECON model</translation>
    </message>
    <message>
        <location filename="../src/SiteconBuildDialogController.cpp" line="159"/>
        <source>alignment_has_gaps</source>
        <translation>Alignment contains gaps</translation>
    </message>
    <message>
        <location filename="../src/SiteconBuildDialogController.cpp" line="163"/>
        <source>alignment_is_empty</source>
        <translation>Alignment is empty</translation>
    </message>
    <message>
        <location filename="../src/SiteconBuildDialogController.cpp" line="167"/>
        <source>alignment_is_not_nucleic</source>
        <translation>Alignment is not nucleic</translation>
    </message>
    <message>
        <location filename="../src/SiteconBuildDialogController.cpp" line="171"/>
        <source>window_greater_then_length</source>
        <translation>Window size is greater than alignment length</translation>
    </message>
    <message>
        <location filename="../src/SiteconBuildDialogController.cpp" line="185"/>
        <source>calculating_ave_disp_matrix</source>
        <translation>Calculating average and dispersion matrixes</translation>
    </message>
    <message>
        <location filename="../src/SiteconBuildDialogController.cpp" line="190"/>
        <source>calculating_weights</source>
        <translation>Calculating weights</translation>
    </message>
    <message>
        <location filename="../src/SiteconBuildDialogController.cpp" line="196"/>
        <source>calculating_firstTypeErr</source>
        <translation>Calibrating first type error</translation>
    </message>
    <message>
        <location filename="../src/SiteconBuildDialogController.cpp" line="202"/>
        <source>calculating_second_type_err</source>
        <translation>Calibrating second type error</translation>
    </message>
</context>
<context>
    <name>GB2::SiteconBuildToFileTask</name>
    <message>
        <location filename="../src/SiteconBuildDialogController.cpp" line="210"/>
        <source>build_sitecon_model</source>
        <translation>Build SITECON model to file</translation>
    </message>
    <message>
        <location filename="../src/SiteconBuildDialogController.cpp" line="220"/>
        <source>input_format_error</source>
        <translation>Unknown alignment format</translation>
    </message>
    <message>
        <location filename="../src/SiteconBuildDialogController.cpp" line="228"/>
        <source>loading_ali</source>
        <translation>Loading alignment</translation>
    </message>
    <message>
        <location filename="../src/SiteconBuildDialogController.cpp" line="247"/>
        <source>no_alignments_found</source>
        <translation>No alignment found</translation>
    </message>
</context>
<context>
    <name>GB2::SiteconIO</name>
    <message>
        <location filename="../src/SiteconIO.cpp" line="79"/>
        <source>not_sitecon_model_file</source>
        <translation>Not a sitecon model</translation>
    </message>
    <message>
        <location filename="../src/SiteconIO.cpp" line="118"/>
        <source>error_parsing_settings_line_%1</source>
        <translation>Error parsing settings, line %1</translation>
    </message>
    <message>
        <location filename="../src/SiteconIO.cpp" line="129"/>
        <source>error_parsing_settings_window_size_%1</source>
        <translation>Error parsing window size: %1</translation>
    </message>
    <message>
        <location filename="../src/SiteconIO.cpp" line="142"/>
        <source>error_parsing_calibration_len_%1</source>
        <translation>Error parsing calibration len: %1</translation>
    </message>
    <message>
        <location filename="../src/SiteconIO.cpp" line="148"/>
        <source>error_parsing_rseed_%1</source>
        <translation>Error parsing RSEED: %1</translation>
    </message>
    <message>
        <location filename="../src/SiteconIO.cpp" line="154"/>
        <location filename="../src/SiteconIO.cpp" line="160"/>
        <source>error_parsing_nsequence_in_ali_%1</source>
        <translation>Error parsing number of sequence in original alignment: %1</translation>
    </message>
    <message>
        <location filename="../src/SiteconIO.cpp" line="168"/>
        <source>illegal_weight_alg_%1</source>
        <translation>Illegal weight algorithm: %1</translation>
    </message>
    <message>
        <location filename="../src/SiteconIO.cpp" line="180"/>
        <source>model_size_not_matched_%1_expected_%2</source>
        <translation>Model size not matched: %1, expected: %2</translation>
    </message>
    <message>
        <location filename="../src/SiteconIO.cpp" line="213"/>
        <source>property_not_recognized_%1</source>
        <translation>Property not recognized: %1</translation>
    </message>
    <message>
        <location filename="../src/SiteconIO.cpp" line="229"/>
        <source>error_parsing_matrix_val_%1_in_line_%2</source>
        <translation>Error parsing matrix value: %1, line %2</translation>
    </message>
    <message>
        <location filename="../src/SiteconIO.cpp" line="247"/>
        <source>error_parsing_errors_line_%1</source>
        <translation>Error parsing &apos;Errors&apos; line %1</translation>
    </message>
    <message>
        <location filename="../src/SiteconIO.cpp" line="256"/>
        <location filename="../src/SiteconIO.cpp" line="261"/>
        <source>error_parsing_error_val_%1</source>
        <translation>Error parsing value: %1</translation>
    </message>
    <message>
        <location filename="../src/SiteconIO.cpp" line="265"/>
        <source>illegal_err_val_%1</source>
        <translation>Illegal value: %1</translation>
    </message>
    <message>
        <location filename="../src/SiteconIO.cpp" line="275"/>
        <source>error_parsing_file_line_%1</source>
        <translation>Error parsing line: %1</translation>
    </message>
    <message>
        <location filename="../src/SiteconIO.cpp" line="284"/>
        <source>ave_props_in_file_%1_not_matched_sdev_props_%2</source>
        <translation>Number of &apos;average&apos; and  &apos;sdev&apos; properties not matches</translation>
    </message>
    <message>
        <location filename="../src/SiteconIO.cpp" line="289"/>
        <source>ave_props_in_file_%1_not_matched_weight_props_%2</source>
        <translation>Number of &apos;average&apos; and &apos;weight&apos; properties not matches</translation>
    </message>
    <message>
        <location filename="../src/SiteconIO.cpp" line="294"/>
        <source>props_in_file_%1_not_matched_actual_props_%2</source>
        <translation>Property in file %1 is not the same as built-in: %2</translation>
    </message>
    <message>
        <location filename="../src/SiteconIO.cpp" line="322"/>
        <source>error_info_not_complete</source>
        <translation>Error info in file is not complete</translation>
    </message>
    <message>
        <location filename="../src/SiteconIO.cpp" line="329"/>
        <source>model_verification_error</source>
        <translation>Model verification error</translation>
    </message>
    <message>
        <location filename="../src/SiteconIO.cpp" line="203"/>
        <source>duplicate_prop_%1</source>
        <translation>Duplicate property: %1</translation>
    </message>
    <message>
        <location filename="../src/SiteconIOWorkers.cpp" line="39"/>
        <location filename="../src/SiteconIOWorkers.cpp" line="105"/>
        <location filename="../src/SiteconIOWorkers.cpp" line="114"/>
        <source>Sitecon model</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/SiteconIOWorkers.cpp" line="53"/>
        <location filename="../src/SiteconIOWorkers.cpp" line="99"/>
        <source>Location</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/SiteconIOWorkers.cpp" line="116"/>
        <source>Read Sitecon model</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/SiteconIOWorkers.cpp" line="107"/>
        <source>Write Sitecon model</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/SiteconIOWorkers.cpp" line="45"/>
        <source>SITECON</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/SiteconIO.cpp" line="22"/>
        <source>Sitecon models</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/SiteconIOWorkers.cpp" line="53"/>
        <source>Location of the data file(s).</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/SiteconIOWorkers.cpp" line="99"/>
        <source>Location hint for the target file.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/SiteconIOWorkers.cpp" line="105"/>
        <source>Input Sitecon model</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/SiteconIOWorkers.cpp" line="107"/>
        <source>Saves all input SITECON profiles to specified location.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/SiteconIOWorkers.cpp" line="114"/>
        <source>Loaded SITECON profile data.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/SiteconIOWorkers.cpp" line="116"/>
        <source>Reads SITECON profiles from file(s). The files can be local or Internet URLs.</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>GB2::SiteconPlugin</name>
    <message>
        <location filename="../src/SiteconPlugin.cpp" line="38"/>
        <source>sitecon_plugin</source>
        <translation>SITECON</translation>
    </message>
    <message>
        <location filename="../src/SiteconPlugin.cpp" line="38"/>
        <source>sitecon_plugin_desc</source>
        <translation>SITECON - is a program package for revealing and analysis of conservative conformational and physicochemical properties in transcription factor binding sites sets.</translation>
    </message>
    <message>
        <location filename="../src/SiteconPlugin.cpp" line="44"/>
        <source>sitecon_build</source>
        <translation>Build new SITECON model from alignment</translation>
    </message>
    <message>
        <location filename="../src/SiteconPlugin.cpp" line="50"/>
        <source>sitecon_menu</source>
        <translation>SITECON</translation>
    </message>
</context>
<context>
    <name>GB2::SiteconReadTask</name>
    <message>
        <location filename="../src/SiteconIO.h" line="31"/>
        <source>Read SITECON model</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>GB2::SiteconSearchDialogController</name>
    <message>
        <location filename="../src/SiteconSearchDialogController.cpp" line="122"/>
        <source>cancel_button</source>
        <translation>Cancel</translation>
    </message>
    <message>
        <location filename="../src/SiteconSearchDialogController.cpp" line="122"/>
        <source>close_button</source>
        <translation>Close</translation>
    </message>
    <message>
        <location filename="../src/SiteconSearchDialogController.cpp" line="134"/>
        <source>progress_%1%_</source>
        <translation>Progress: %1% </translation>
    </message>
    <message>
        <location filename="../src/SiteconSearchDialogController.cpp" line="136"/>
        <source>%1_results_found.</source>
        <translation>%1 results found</translation>
    </message>
    <message>
        <location filename="../src/SiteconSearchDialogController.cpp" line="155"/>
        <source>select_file_with_model</source>
        <translation>Select file with SITECON model</translation>
    </message>
    <message>
        <location filename="../src/SiteconSearchDialogController.cpp" line="164"/>
        <location filename="../src/SiteconSearchDialogController.cpp" line="262"/>
        <location filename="../src/SiteconSearchDialogController.cpp" line="273"/>
        <location filename="../src/SiteconSearchDialogController.cpp" line="286"/>
        <source>error</source>
        <translation>Error</translation>
    </message>
    <message>
        <location filename="../src/SiteconSearchDialogController.cpp" line="199"/>
        <source>%1%	err1=%2	err2=%3</source>
        <translation>%1%,  first type error %2,  second type error %3</translation>
    </message>
    <message>
        <location filename="../src/SiteconSearchDialogController.cpp" line="262"/>
        <source>model not selected</source>
        <translation>No model selected</translation>
    </message>
    <message>
        <location filename="../src/SiteconSearchDialogController.cpp" line="273"/>
        <source>range_is_too_small</source>
        <translation>Range is too small</translation>
    </message>
    <message>
        <location filename="../src/SiteconSearchDialogController.cpp" line="286"/>
        <source>error_parsing_min_score</source>
        <translation>Error parsing minumum score</translation>
    </message>
    <message>
        <location filename="../src/SiteconSearchDialogController.cpp" line="351"/>
        <source>complement_strand</source>
        <translation>Complement strand</translation>
    </message>
    <message>
        <location filename="../src/SiteconSearchDialogController.cpp" line="351"/>
        <source>direct_strand</source>
        <translation>Direct strand</translation>
    </message>
</context>
<context>
    <name>GB2::SiteconSearchTask</name>
    <message>
        <location filename="../src/SiteconSearchTask.cpp" line="6"/>
        <source>sitecon_search</source>
        <translation>SITECON search</translation>
    </message>
    <message>
        <location filename="../src/SiteconSearchTask.cpp" line="19"/>
        <source>sitecon_search_parallel</source>
        <translation>SITECON search parallel subtask</translation>
    </message>
    <message>
        <location filename="../src/SiteconSearchTask.cpp" line="39"/>
        <source>internal_error_invalid_psum:%1</source>
        <translation>Internal error: invalid PSUM: %1</translation>
    </message>
</context>
<context>
    <name>GB2::SiteconWriteTask</name>
    <message>
        <location filename="../src/SiteconIO.h" line="44"/>
        <source>Save SITECON model</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>SiteconBuildDialog</name>
    <message>
        <location filename="../src/ui/SiteconBuildDialog.ui" line="13"/>
        <source>sitecon_build_caption</source>
        <translation>SITECON build</translation>
    </message>
    <message>
        <location filename="../src/ui/SiteconBuildDialog.ui" line="21"/>
        <source>input_ali</source>
        <translation>Iinput alignment (nucleic)</translation>
    </message>
    <message>
        <location filename="../src/ui/SiteconBuildDialog.ui" line="31"/>
        <location filename="../src/ui/SiteconBuildDialog.ui" line="48"/>
        <source>...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/SiteconBuildDialog.ui" line="38"/>
        <source>out_profile</source>
        <translation>Output model</translation>
    </message>
    <message>
        <location filename="../src/ui/SiteconBuildDialog.ui" line="57"/>
        <source>options</source>
        <translation>Options</translation>
    </message>
    <message>
        <location filename="../src/ui/SiteconBuildDialog.ui" line="66"/>
        <source>window_size</source>
        <translation>Window size</translation>
    </message>
    <message>
        <location filename="../src/ui/SiteconBuildDialog.ui" line="98"/>
        <source>bp</source>
        <translation>bp</translation>
    </message>
    <message>
        <location filename="../src/ui/SiteconBuildDialog.ui" line="117"/>
        <source>calibration_random_seed</source>
        <translation>Calibration random seed</translation>
    </message>
    <message>
        <location filename="../src/ui/SiteconBuildDialog.ui" line="168"/>
        <source>calibration_sequence_len</source>
        <translation>Calibration sequence length</translation>
    </message>
    <message>
        <location filename="../src/ui/SiteconBuildDialog.ui" line="201"/>
        <source>       100 Kb</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/SiteconBuildDialog.ui" line="206"/>
        <source>       500 Kb</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/SiteconBuildDialog.ui" line="211"/>
        <source>         1 Mb</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/SiteconBuildDialog.ui" line="216"/>
        <source>         5 Mb</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/SiteconBuildDialog.ui" line="227"/>
        <source>weight_alg</source>
        <translation>Weight algorithm</translation>
    </message>
    <message>
        <location filename="../src/ui/SiteconBuildDialog.ui" line="285"/>
        <source>default_status</source>
        <translation> </translation>
    </message>
    <message>
        <location filename="../src/ui/SiteconBuildDialog.ui" line="305"/>
        <source>start_button</source>
        <translation>Build</translation>
    </message>
    <message>
        <location filename="../src/ui/SiteconBuildDialog.ui" line="312"/>
        <source>cancel_butotn</source>
        <translation>Cancel</translation>
    </message>
    <message>
        <location filename="../src/ui/SiteconBuildDialog.ui" line="254"/>
        <source>       None</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/SiteconBuildDialog.ui" line="259"/>
        <source>  Algorithm N2</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/SiteconBuildWorker.cpp" line="51"/>
        <location filename="../src/ui/SiteconBuildDialog.ui" line="63"/>
        <location filename="../src/ui/SiteconBuildDialog.ui" line="92"/>
        <source>win_tip</source>
        <translation>Window size must be not less than the consensus sequence for this particular site and should not exceed TFBS alignment length. Optimal is to choose this parameter a bit less than the alignment length, but not more than 50.</translation>
    </message>
    <message>
        <location filename="../src/SiteconBuildWorker.cpp" line="52"/>
        <location filename="../src/ui/SiteconBuildDialog.ui" line="165"/>
        <location filename="../src/ui/SiteconBuildDialog.ui" line="188"/>
        <source>seq_len_tip</source>
        <translation>Length of random synthetic sequences used to calibrate the profile. Should not be less than window size.</translation>
    </message>
    <message>
        <location filename="../src/SiteconBuildWorker.cpp" line="53"/>
        <location filename="../src/ui/SiteconBuildDialog.ui" line="114"/>
        <location filename="../src/ui/SiteconBuildDialog.ui" line="143"/>
        <source>seed_tip</source>
        <translation>The random seed, where &lt;n&gt; is a positive integer. You can use this option to generate reproducible results for different runs on the same data.</translation>
    </message>
    <message>
        <location filename="../src/SiteconBuildWorker.cpp" line="54"/>
        <location filename="../src/ui/SiteconBuildDialog.ui" line="224"/>
        <location filename="../src/ui/SiteconBuildDialog.ui" line="247"/>
        <source>algo_tip</source>
        <translation>Optional feature, in most cases applying no weight will fit. In some cases choosing algorithm 2 will increase the recognition quality.</translation>
    </message>
</context>
<context>
    <name>SiteconSearchDialog</name>
    <message>
        <location filename="../src/ui/SiteconSearchDialog.ui" line="13"/>
        <source>sitecon_search_title</source>
        <translation>SITECON search</translation>
    </message>
    <message>
        <location filename="../src/ui/SiteconSearchDialog.ui" line="21"/>
        <source>sitecon_model_file</source>
        <translation>File with model</translation>
    </message>
    <message>
        <location filename="../src/ui/SiteconSearchDialog.ui" line="35"/>
        <source>...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/SiteconSearchDialog.ui" line="45"/>
        <source>error_level</source>
        <translation>Threshold</translation>
    </message>
    <message>
        <location filename="../src/ui/SiteconSearchDialog.ui" line="75"/>
        <source>strand_group</source>
        <translation>Strands</translation>
    </message>
    <message>
        <location filename="../src/ui/SiteconSearchDialog.ui" line="81"/>
        <source>strand_both</source>
        <translation>Both strands</translation>
    </message>
    <message>
        <location filename="../src/ui/SiteconSearchDialog.ui" line="94"/>
        <source>strand_direct_wit</source>
        <translation>Search in direct strand only</translation>
    </message>
    <message>
        <location filename="../src/ui/SiteconSearchDialog.ui" line="97"/>
        <source>strand_direct_label</source>
        <translation>Direct strand</translation>
    </message>
    <message>
        <location filename="../src/ui/SiteconSearchDialog.ui" line="113"/>
        <source>strand_complement_wit</source>
        <translation>Search in complement strand</translation>
    </message>
    <message>
        <location filename="../src/ui/SiteconSearchDialog.ui" line="116"/>
        <source>strand_complement_label</source>
        <translation>Complement strand</translation>
    </message>
    <message>
        <location filename="../src/ui/SiteconSearchDialog.ui" line="129"/>
        <location filename="../src/ui/SiteconSearchDialog.ui" line="264"/>
        <source>range</source>
        <translation>Range</translation>
    </message>
    <message>
        <location filename="../src/ui/SiteconSearchDialog.ui" line="137"/>
        <source>sequence_range</source>
        <translation>Whole sequence</translation>
    </message>
    <message>
        <location filename="../src/ui/SiteconSearchDialog.ui" line="164"/>
        <source>selection_range</source>
        <translation>Selection range</translation>
    </message>
    <message>
        <location filename="../src/ui/SiteconSearchDialog.ui" line="188"/>
        <source>custom_range</source>
        <translation>Custom range</translation>
    </message>
    <message>
        <location filename="../src/ui/SiteconSearchDialog.ui" line="221"/>
        <source>-</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/SiteconSearchDialog.ui" line="269"/>
        <source>strand</source>
        <translation>Strand</translation>
    </message>
    <message>
        <location filename="../src/ui/SiteconSearchDialog.ui" line="274"/>
        <source>psum</source>
        <translation>PSUM</translation>
    </message>
    <message>
        <location filename="../src/ui/SiteconSearchDialog.ui" line="279"/>
        <source>err1</source>
        <translation>First type error</translation>
    </message>
    <message>
        <location filename="../src/ui/SiteconSearchDialog.ui" line="284"/>
        <source>err2</source>
        <translation>Second type error</translation>
    </message>
    <message>
        <location filename="../src/ui/SiteconSearchDialog.ui" line="294"/>
        <source>clear_results</source>
        <translation>Clear results</translation>
    </message>
    <message>
        <location filename="../src/ui/SiteconSearchDialog.ui" line="301"/>
        <source>save_as_annotations</source>
        <translation>Save as annotations...</translation>
    </message>
    <message>
        <location filename="../src/ui/SiteconSearchDialog.ui" line="325"/>
        <source>status</source>
        <translation>Ready</translation>
    </message>
    <message>
        <location filename="../src/ui/SiteconSearchDialog.ui" line="345"/>
        <source>search</source>
        <translation>Search</translation>
    </message>
    <message>
        <location filename="../src/ui/SiteconSearchDialog.ui" line="352"/>
        <source>cancel</source>
        <translation>Cancel</translation>
    </message>
    <message>
        <location filename="../src/SiteconSearchWorker.cpp" line="55"/>
        <location filename="../src/ui/SiteconSearchDialog.ui" line="42"/>
        <location filename="../src/ui/SiteconSearchDialog.ui" line="58"/>
        <source>min_err_tip</source>
        <translation>Recognition quality threshold, should be less than 100%. Choosing too low threshold will lead to recognition of too many TFBS recognised with too low trustworthiness. Choosing too high threshold may result in no TFBS recognised.</translation>
    </message>
</context>
</TS>
